@@ -30,6 +30,9 @@
 #include "libtest/persist_lib.h"
 
 #include <stdlib.h>
+#include <glib/gprintf.h>
+
+MsgFormatOptions parse_options;
 
 typedef struct _LogMessageTestParams
 {
@@ -75,7 +78,7 @@ _construct_merged_message(const gchar *name, const gchar *value)
 
 static void
 assert_log_msg_clear_clears_all_properties(LogMessage *message, NVHandle nv_handle,
-    NVHandle sd_handle, const gchar *tag_name)
+                                           NVHandle sd_handle, const gchar *tag_name)
 {
   log_msg_clear(message);
 
@@ -96,7 +99,7 @@ assert_sdata_value_with_seqnum_equals(LogMessage *msg, guint32 seq_num, const gc
   GString *result = g_string_sized_new(0);
 
   log_msg_append_format_sdata(msg, result, seq_num);
-  cr_assert_str_eq(result->str, expected, "SDATA value does not match");
+  cr_assert_str_eq(result->str, expected, "SDATA value does not match, '%s' vs '%s'", expected, result->str);
   g_string_free(result, TRUE);
 }
 
@@ -150,7 +153,7 @@ void
 setup(void)
 {
   app_startup();
-  init_and_load_syslogformat_module();
+  init_parse_options_and_load_syslogformat(&parse_options);
 }
 
 void
@@ -175,9 +178,9 @@ Test(log_message, test_log_message_can_be_cleared)
   log_message_test_params_clone_message(params);
 
   assert_log_msg_clear_clears_all_properties(params->message, params->nv_handle,
-      params->sd_handle, params->tag_name);
+                                             params->sd_handle, params->tag_name);
   assert_log_msg_clear_clears_all_properties(params->cloned_message, params->nv_handle,
-      params->sd_handle, params->tag_name);
+                                             params->sd_handle, params->tag_name);
 
   log_message_test_params_free(params);
 }
@@ -311,8 +314,8 @@ Test(log_message, test_log_msg_get_value_with_time_related_macro)
   const char *date_value;
 
   msg = log_msg_new_empty();
-  msg->timestamps[LM_TS_STAMP].tv_sec = 1389783444;
-  msg->timestamps[LM_TS_STAMP].zone_offset = 3600;
+  msg->timestamps[LM_TS_STAMP].ut_sec = 1389783444;
+  msg->timestamps[LM_TS_STAMP].ut_gmtoff = 3600;
 
   handle = log_msg_get_value_handle("ISODATE");
   date_value = log_msg_get_value(msg, handle, &value_len);
@@ -325,10 +328,55 @@ Test(log_message, test_local_logmsg_created_with_the_right_flags_and_timestamps)
 {
   LogMessage *msg = log_msg_new_local();
 
-  gboolean are_equals = log_stamp_eq(&msg->timestamps[LM_TS_STAMP], &msg->timestamps[LM_TS_RECVD]);
+  gboolean are_equals = unix_time_eq(&msg->timestamps[LM_TS_STAMP], &msg->timestamps[LM_TS_RECVD]);
 
   cr_assert_neq((msg->flags & LF_LOCAL), 0, "LogMessage created by log_msg_new_local() should have LF_LOCAL flag set");
   cr_assert(are_equals, "The timestamps in a LogMessage created by log_msg_new_local() should be equals");
+
+  log_msg_unref(msg);
+}
+
+Test(log_message, test_sdata_sanitization)
+{
+  LogMessage *msg;
+  /* These keys looks strange, but JSON object can be parsed to SDATA,
+   * so the key could contain any character, while the specification
+   * does not declare any way to encode the keys, just the values.
+   * The goal is to have a syntactically valid syslog message.
+   *
+   * Block names are sanitized with the same function as the keys,
+   * thus no need for exhaust testing, added just one case to the end
+   * to see if business logic applied. */
+
+  msg = log_msg_new_empty();
+  log_msg_set_value_by_name(msg, ".SDATA.foo.bar[0]", "value[0]", -1);
+  assert_sdata_value_equals(msg, "[foo bar%5B0%5D=\"value[0\\]\"]");
+  log_msg_unref(msg);
+
+  msg = log_msg_new_empty();
+  log_msg_set_value_by_name(msg, ".SDATA.foo.bácsi", "bácsi", -1);
+  assert_sdata_value_equals(msg, "[foo b%C3%A1csi=\"bácsi\"]");
+  log_msg_unref(msg);
+
+  msg = log_msg_new_empty();
+  log_msg_set_value_by_name(msg, ".SDATA.foo.sp ace", "sp ace", -1);
+  assert_sdata_value_equals(msg, "[foo sp%20ace=\"sp ace\"]");
+  log_msg_unref(msg);
+
+  msg = log_msg_new_empty();
+  log_msg_set_value_by_name(msg, ".SDATA.foo.eq=al", "eq=al", -1);
+  assert_sdata_value_equals(msg, "[foo eq%3Dal=\"eq=al\"]");
+  log_msg_unref(msg);
+
+  msg = log_msg_new_empty();
+  log_msg_set_value_by_name(msg, ".SDATA.foo.quo\"te", "quo\"te", -1);
+  assert_sdata_value_equals(msg, "[foo quo%22te=\"quo\\\"te\"]");
+  log_msg_unref(msg);
+
+  msg = log_msg_new_empty();
+  log_msg_set_value_by_name(msg, ".SDATA.fo@o[0].bar", "value", -1);
+  assert_sdata_value_equals(msg, "[fo@o%5B0%5D bar=\"value\"]");
+  log_msg_unref(msg);
 }
 
 Test(log_message, test_sdata_value_is_updated_by_sdata_name_value_pairs)
@@ -382,3 +430,111 @@ Test(log_message, test_sdata_value_omits_unset_values)
   assert_sdata_value_equals(msg, "");
   log_msg_unref(msg);
 }
+
+#define DEFUN_KEY_VALUE(name, key, value, size) \
+  gchar name ## _key[size]; \
+  gchar name ## _value[size]; \
+  name ## _key[size-1] = name ## _value[size-1] = 0; \
+  memset(name ## _key, key, sizeof(name ##_key)-1); \
+  memset(name ## _value, value, sizeof(name ##_value)-1); \
+
+
+typedef struct
+{
+  gssize nvtable_size_old;
+  gssize nvtable_size_new;
+  gssize msg_size_old;
+  gssize msg_size_new;
+} sizes_t;
+
+static sizes_t
+add_key_value(LogMessage *msg, gchar *key, gchar *value)
+{
+  sizes_t sizes;
+  sizes.msg_size_old = log_msg_get_size(msg);
+  sizes.nvtable_size_old = nv_table_get_memory_consumption(msg->payload);
+  log_msg_set_value_by_name(msg, key, value, -1);
+  sizes.nvtable_size_new = nv_table_get_memory_consumption(msg->payload);
+  sizes.msg_size_new = log_msg_get_size(msg);
+  return sizes;
+}
+
+
+static void
+test_with_sdata(LogMessage *msg, guint32 old_msg_size)
+{
+  sizes_t sizes;
+  gchar key[]          = ".SDATA.**";
+  gchar value[] = "AAAAAAA";
+
+  guint32 single_sdata_kv_size;
+  guint32 sdata_payload_array_size;
+
+  const char iter_length = 17;
+
+  for (char i = 0; i < iter_length; i++)
+    {
+      g_sprintf(key, ".SDATA.%02d", i);
+      sizes = add_key_value(msg, key, value);
+
+      single_sdata_kv_size = NV_ENTRY_DIRECT_HDR + NV_TABLE_BOUND(strlen(key)+1 + strlen(value)+1);
+
+      /* i+1 is stored, but the sdata array size is calculated when adding the i-th */
+      sdata_payload_array_size = STRICT_ROUND_TO_NEXT_EIGHT(i) * sizeof(msg->sdata[0]);
+      cr_assert_eq(old_msg_size + (i+1) * single_sdata_kv_size + sdata_payload_array_size, sizes.msg_size_new);
+    }
+}
+
+#define SMALL_LENGTH 10
+#define LARGE_LENGTH 256
+
+Test(log_message, test_message_size)
+{
+  LogMessage *msg = log_msg_new_empty();
+
+  sizes_t sizes;
+
+  DEFUN_KEY_VALUE(small, 'C', 'D', SMALL_LENGTH);
+  sizes = add_key_value(msg, small_key, small_value);
+  // (SMALL_LENGTH-1)*'C'+'\0' + (SMALL_LENGTH-1)*'D'+'\0'
+  guint32 entry_size = NV_ENTRY_DIRECT_HDR + NV_TABLE_BOUND(SMALL_LENGTH + SMALL_LENGTH);
+  cr_assert_eq(sizes.nvtable_size_old + entry_size, sizes.nvtable_size_new);
+  cr_assert_eq(sizes.msg_size_old + entry_size, sizes.msg_size_new);  // Size increased because of nvtable
+
+  guint32 msg_size = sizes.msg_size_new;
+  log_msg_set_tag_by_name(msg, "test_tag_storage");
+  cr_assert(log_msg_is_tag_by_name(msg, "test_tag_storage"));
+  cr_assert_eq(msg_size, log_msg_get_size(msg)); // Tag is not increased until tag id 65
+
+  char *tag_name = strdup("00tagname");
+  // (*8 to convert ot bits) + no need plus 1 bcause we already added one tag: test_tag_storage
+  for (int i = 0; i < GLIB_SIZEOF_LONG*8; i++)
+    {
+      sprintf(tag_name, "%dtagname", i);
+      log_msg_set_tag_by_name(msg, tag_name);
+    }
+  free(tag_name);
+  cr_assert_eq(msg_size + 2*GLIB_SIZEOF_LONG, log_msg_get_size(msg));
+
+
+  DEFUN_KEY_VALUE(big, 'A', 'B', LARGE_LENGTH);
+  sizes = add_key_value(msg, big_key, big_value); // nvtable is expanded
+  entry_size = NV_ENTRY_DIRECT_HDR + NV_TABLE_BOUND(LARGE_LENGTH + LARGE_LENGTH);
+  cr_assert_eq(sizes.nvtable_size_old + entry_size, sizes.nvtable_size_new); // but only increased by the entry
+  cr_assert_eq(sizes.msg_size_old + entry_size, sizes.msg_size_new);  // nvtable is doubled
+
+  test_with_sdata(msg, sizes.msg_size_new);
+
+  log_msg_unref(msg);
+}
+
+Test(log_message, when_get_indirect_value_with_null_value_len_abort_instead_of_sigsegv, .signal=SIGABRT)
+{
+  LogMessageTestParams *params = log_message_test_params_new();
+
+  NVHandle indirect = log_msg_get_value_handle("INDIRECT");
+  log_msg_set_value_indirect(params->message, indirect, params->nv_handle, 0, 0, 5);
+  log_msg_get_value(params->message, indirect, NULL);
+
+  log_message_test_params_free(params);
+}
