@@ -29,16 +29,17 @@
 extern int rewrite_expr_debug;
 int rewrite_expr_parse(CfgLexer *lexer, LogExprNode **node, gpointer arg);
 
-static CfgLexerKeyword rewrite_expr_keywords[] = {
+static CfgLexerKeyword rewrite_expr_keywords[] =
+{
   { "set",                KW_SET },
   { "unset",              KW_UNSET },
   { "subst",              KW_SUBST },
   { "set_tag",            KW_SET_TAG },
   { "clear_tag",          KW_CLEAR_TAG },
+  { "set_severity",       KW_SET_SEVERITY },
 
-  { "condition",          KW_CONDITION },
   { "groupset",           KW_GROUP_SET },
-  { "value",              KW_VALUE },
+  { "groupunset",         KW_GROUP_UNSET },
   { "values",             KW_VALUES },
 
   { NULL }
