@@ -34,6 +34,7 @@
 #include "cfg.h"
 #include "plugin.h"
 #include "scratch-buffers.h"
+#include "hostname.h"
 
 #include <time.h>
 #include <stdlib.h>
@@ -145,9 +146,14 @@ Test(template, test_macros)
 
   assert_template_format("$FACILITY", "local3");
   assert_template_format("$FACILITY_NUM", "19");
+
+  assert_template_format("$SEVERITY", "err");
+  assert_template_format("$SEVERITY_NUM", "3");
+
   assert_template_format("$PRIORITY", "err");
   assert_template_format("$LEVEL", "err");
   assert_template_format("$LEVEL_NUM", "3");
+
   assert_template_format("$TAG", "9b");
   assert_template_format("$TAGS", "alma,korte,citrom,\"tag,containing,comma\"");
   assert_template_format("$PRI", "155");
@@ -234,6 +240,19 @@ Test(template, test_macros)
   assert_template_format("$UNIQID", "cafebabe@000000000000022b");
 }
 
+Test(template, test_loghost_macro)
+{
+  const gchar *fqdn = get_local_hostname_fqdn();
+  const gchar *short_name = get_local_hostname_short();
+
+  /* by default $LOGHOST is using fqdn as the template options we are using uses use_fqdn by default */
+  cr_assert_not(configuration->template_options.use_fqdn);
+  configuration->template_options.use_fqdn = TRUE;
+  assert_template_format("$LOGHOST", fqdn);
+  configuration->template_options.use_fqdn = FALSE;
+  assert_template_format("$LOGHOST", short_name);
+}
+
 Test(template, test_nvpairs)
 {
   assert_template_format("$PROGRAM/var/log/messages/$HOST/$HOST_FROM/$MONTH$DAY${QQQQQ}valami",
