@@ -152,11 +152,11 @@ extern int affile_debug;
     KW_TEMPLATE_ESCAPE = 10271,
     KW_TEMPLATE_FUNCTION = 10272,
     KW_DEFAULT_FACILITY = 10300,
-    KW_DEFAULT_LEVEL = 10301,
+    KW_DEFAULT_SEVERITY = 10301,
     KW_PORT = 10323,
     KW_USE_TIME_RECVD = 10340,
     KW_FACILITY = 10350,
-    KW_LEVEL = 10351,
+    KW_SEVERITY = 10351,
     KW_HOST = 10352,
     KW_MATCH = 10353,
     KW_MESSAGE = 10354,
@@ -164,6 +164,8 @@ extern int affile_debug;
     KW_TAGS = 10356,
     KW_NETMASK6 = 10357,
     KW_REWRITE = 10370,
+    KW_CONDITION = 10371,
+    KW_VALUE = 10372,
     KW_YES = 10380,
     KW_NO = 10381,
     KW_IFDEF = 10410,
@@ -201,13 +203,15 @@ extern int affile_debug;
     KW_MULTI_LINE_MODE = 10520,
     KW_MULTI_LINE_PREFIX = 10521,
     KW_MULTI_LINE_GARBAGE = 10522,
-    KW_WILDCARD_FILE = 10523,
-    KW_BASE_DIR = 10524,
-    KW_FILENAME_PATTERN = 10525,
-    KW_RECURSIVE = 10526,
-    KW_MAX_FILES = 10527,
-    KW_MONITOR_METHOD = 10528,
-    KW_STDIN = 10529
+    KW_MULTI_LINE_TIMEOUT = 10523,
+    KW_WILDCARD_FILE = 10524,
+    KW_BASE_DIR = 10525,
+    KW_FILENAME_PATTERN = 10526,
+    KW_RECURSIVE = 10527,
+    KW_MAX_FILES = 10528,
+    KW_MONITOR_METHOD = 10529,
+    KW_FORCE_DIRECTORY_POLLING = 10530,
+    KW_STDIN = 10531
   };
 #endif
 /* Tokens.  */
@@ -318,11 +322,11 @@ extern int affile_debug;
 #define KW_TEMPLATE_ESCAPE 10271
 #define KW_TEMPLATE_FUNCTION 10272
 #define KW_DEFAULT_FACILITY 10300
-#define KW_DEFAULT_LEVEL 10301
+#define KW_DEFAULT_SEVERITY 10301
 #define KW_PORT 10323
 #define KW_USE_TIME_RECVD 10340
 #define KW_FACILITY 10350
-#define KW_LEVEL 10351
+#define KW_SEVERITY 10351
 #define KW_HOST 10352
 #define KW_MATCH 10353
 #define KW_MESSAGE 10354
@@ -330,6 +334,8 @@ extern int affile_debug;
 #define KW_TAGS 10356
 #define KW_NETMASK6 10357
 #define KW_REWRITE 10370
+#define KW_CONDITION 10371
+#define KW_VALUE 10372
 #define KW_YES 10380
 #define KW_NO 10381
 #define KW_IFDEF 10410
@@ -367,13 +373,15 @@ extern int affile_debug;
 #define KW_MULTI_LINE_MODE 10520
 #define KW_MULTI_LINE_PREFIX 10521
 #define KW_MULTI_LINE_GARBAGE 10522
-#define KW_WILDCARD_FILE 10523
-#define KW_BASE_DIR 10524
-#define KW_FILENAME_PATTERN 10525
-#define KW_RECURSIVE 10526
-#define KW_MAX_FILES 10527
-#define KW_MONITOR_METHOD 10528
-#define KW_STDIN 10529
+#define KW_MULTI_LINE_TIMEOUT 10523
+#define KW_WILDCARD_FILE 10524
+#define KW_BASE_DIR 10525
+#define KW_FILENAME_PATTERN 10526
+#define KW_RECURSIVE 10527
+#define KW_MAX_FILES 10528
+#define KW_MONITOR_METHOD 10529
+#define KW_FORCE_DIRECTORY_POLLING 10530
+#define KW_STDIN 10531
 
 /* Value type.  */
 
