@@ -99,7 +99,8 @@ extern int afsocket_debug;
     KW_CIPHER_SUITE = 20052,
     KW_ECDH_CURVE_LIST = 20053,
     KW_SSL_OPTIONS = 20054,
-    KW_ALLOW_COMPRESS = 20055,
+    KW_SNI = 20055,
+    KW_ALLOW_COMPRESS = 20056,
     LL_CONTEXT_ROOT = 1,
     LL_CONTEXT_DESTINATION = 2,
     LL_CONTEXT_SOURCE = 3,
@@ -207,11 +208,11 @@ extern int afsocket_debug;
     KW_TEMPLATE_ESCAPE = 10271,
     KW_TEMPLATE_FUNCTION = 10272,
     KW_DEFAULT_FACILITY = 10300,
-    KW_DEFAULT_LEVEL = 10301,
+    KW_DEFAULT_SEVERITY = 10301,
     KW_PORT = 10323,
     KW_USE_TIME_RECVD = 10340,
     KW_FACILITY = 10350,
-    KW_LEVEL = 10351,
+    KW_SEVERITY = 10351,
     KW_HOST = 10352,
     KW_MATCH = 10353,
     KW_MESSAGE = 10354,
@@ -219,6 +220,8 @@ extern int afsocket_debug;
     KW_TAGS = 10356,
     KW_NETMASK6 = 10357,
     KW_REWRITE = 10370,
+    KW_CONDITION = 10371,
+    KW_VALUE = 10372,
     KW_YES = 10380,
     KW_NO = 10381,
     KW_IFDEF = 10410,
@@ -305,7 +308,8 @@ extern int afsocket_debug;
 #define KW_CIPHER_SUITE 20052
 #define KW_ECDH_CURVE_LIST 20053
 #define KW_SSL_OPTIONS 20054
-#define KW_ALLOW_COMPRESS 20055
+#define KW_SNI 20055
+#define KW_ALLOW_COMPRESS 20056
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -413,11 +417,11 @@ extern int afsocket_debug;
 #define KW_TEMPLATE_ESCAPE 10271
 #define KW_TEMPLATE_FUNCTION 10272
 #define KW_DEFAULT_FACILITY 10300
-#define KW_DEFAULT_LEVEL 10301
+#define KW_DEFAULT_SEVERITY 10301
 #define KW_PORT 10323
 #define KW_USE_TIME_RECVD 10340
 #define KW_FACILITY 10350
-#define KW_LEVEL 10351
+#define KW_SEVERITY 10351
 #define KW_HOST 10352
 #define KW_MATCH 10353
 #define KW_MESSAGE 10354
@@ -425,6 +429,8 @@ extern int afsocket_debug;
 #define KW_TAGS 10356
 #define KW_NETMASK6 10357
 #define KW_REWRITE 10370
+#define KW_CONDITION 10371
+#define KW_VALUE 10372
 #define KW_YES 10380
 #define KW_NO 10381
 #define KW_IFDEF 10410
