@@ -152,11 +152,11 @@ extern int dbparser_debug;
     KW_TEMPLATE_ESCAPE = 10271,
     KW_TEMPLATE_FUNCTION = 10272,
     KW_DEFAULT_FACILITY = 10300,
-    KW_DEFAULT_LEVEL = 10301,
+    KW_DEFAULT_SEVERITY = 10301,
     KW_PORT = 10323,
     KW_USE_TIME_RECVD = 10340,
     KW_FACILITY = 10350,
-    KW_LEVEL = 10351,
+    KW_SEVERITY = 10351,
     KW_HOST = 10352,
     KW_MATCH = 10353,
     KW_MESSAGE = 10354,
@@ -164,6 +164,8 @@ extern int dbparser_debug;
     KW_TAGS = 10356,
     KW_NETMASK6 = 10357,
     KW_REWRITE = 10370,
+    KW_CONDITION = 10371,
+    KW_VALUE = 10372,
     KW_YES = 10380,
     KW_NO = 10381,
     KW_IFDEF = 10410,
@@ -202,12 +204,11 @@ extern int dbparser_debug;
     KW_WHERE = 10521,
     KW_HAVING = 10522,
     KW_AGGREGATE = 10523,
-    KW_VALUE = 10524,
-    KW_DROP_UNMATCHED = 10525,
-    KW_FILE = 10526,
-    KW_PROGRAM_TEMPLATE = 10527,
-    KW_MESSAGE_TEMPLATE = 10528,
-    KW_SORT_KEY = 10529
+    KW_DROP_UNMATCHED = 10524,
+    KW_FILE = 10525,
+    KW_PROGRAM_TEMPLATE = 10526,
+    KW_MESSAGE_TEMPLATE = 10527,
+    KW_SORT_KEY = 10528
   };
 #endif
 /* Tokens.  */
@@ -318,11 +319,11 @@ extern int dbparser_debug;
 #define KW_TEMPLATE_ESCAPE 10271
 #define KW_TEMPLATE_FUNCTION 10272
 #define KW_DEFAULT_FACILITY 10300
-#define KW_DEFAULT_LEVEL 10301
+#define KW_DEFAULT_SEVERITY 10301
 #define KW_PORT 10323
 #define KW_USE_TIME_RECVD 10340
 #define KW_FACILITY 10350
-#define KW_LEVEL 10351
+#define KW_SEVERITY 10351
 #define KW_HOST 10352
 #define KW_MATCH 10353
 #define KW_MESSAGE 10354
@@ -330,6 +331,8 @@ extern int dbparser_debug;
 #define KW_TAGS 10356
 #define KW_NETMASK6 10357
 #define KW_REWRITE 10370
+#define KW_CONDITION 10371
+#define KW_VALUE 10372
 #define KW_YES 10380
 #define KW_NO 10381
 #define KW_IFDEF 10410
@@ -368,12 +371,11 @@ extern int dbparser_debug;
 #define KW_WHERE 10521
 #define KW_HAVING 10522
 #define KW_AGGREGATE 10523
-#define KW_VALUE 10524
-#define KW_DROP_UNMATCHED 10525
-#define KW_FILE 10526
-#define KW_PROGRAM_TEMPLATE 10527
-#define KW_MESSAGE_TEMPLATE 10528
-#define KW_SORT_KEY 10529
+#define KW_DROP_UNMATCHED 10524
+#define KW_FILE 10525
+#define KW_PROGRAM_TEMPLATE 10526
+#define KW_MESSAGE_TEMPLATE 10527
+#define KW_SORT_KEY 10528
 
 /* Value type.  */
 
