@@ -70,6 +70,11 @@ extern int http_debug;
     KW_WORKERS = 10537,
     KW_ACCEPT_REDIRECTS = 10538,
     KW_AUTH_HEADER = 10539,
+    KW_RESPONSE_ACTION = 10540,
+    KW_SUCCESS = 10541,
+    KW_RETRY = 10542,
+    KW_DROP = 10543,
+    KW_DISCONNECT = 10544,
     LL_CONTEXT_ROOT = 1,
     LL_CONTEXT_DESTINATION = 2,
     LL_CONTEXT_SOURCE = 3,
@@ -177,11 +182,11 @@ extern int http_debug;
     KW_TEMPLATE_ESCAPE = 10271,
     KW_TEMPLATE_FUNCTION = 10272,
     KW_DEFAULT_FACILITY = 10300,
-    KW_DEFAULT_LEVEL = 10301,
+    KW_DEFAULT_SEVERITY = 10301,
     KW_PORT = 10323,
     KW_USE_TIME_RECVD = 10340,
     KW_FACILITY = 10350,
-    KW_LEVEL = 10351,
+    KW_SEVERITY = 10351,
     KW_HOST = 10352,
     KW_MATCH = 10353,
     KW_MESSAGE = 10354,
@@ -189,6 +194,8 @@ extern int http_debug;
     KW_TAGS = 10356,
     KW_NETMASK6 = 10357,
     KW_REWRITE = 10370,
+    KW_CONDITION = 10371,
+    KW_VALUE = 10372,
     KW_YES = 10380,
     KW_NO = 10381,
     KW_IFDEF = 10410,
@@ -246,6 +253,11 @@ extern int http_debug;
 #define KW_WORKERS 10537
 #define KW_ACCEPT_REDIRECTS 10538
 #define KW_AUTH_HEADER 10539
+#define KW_RESPONSE_ACTION 10540
+#define KW_SUCCESS 10541
+#define KW_RETRY 10542
+#define KW_DROP 10543
+#define KW_DISCONNECT 10544
 #define LL_CONTEXT_ROOT 1
 #define LL_CONTEXT_DESTINATION 2
 #define LL_CONTEXT_SOURCE 3
@@ -353,11 +365,11 @@ extern int http_debug;
 #define KW_TEMPLATE_ESCAPE 10271
 #define KW_TEMPLATE_FUNCTION 10272
 #define KW_DEFAULT_FACILITY 10300
-#define KW_DEFAULT_LEVEL 10301
+#define KW_DEFAULT_SEVERITY 10301
 #define KW_PORT 10323
 #define KW_USE_TIME_RECVD 10340
 #define KW_FACILITY 10350
-#define KW_LEVEL 10351
+#define KW_SEVERITY 10351
 #define KW_HOST 10352
 #define KW_MATCH 10353
 #define KW_MESSAGE 10354
@@ -365,6 +377,8 @@ extern int http_debug;
 #define KW_TAGS 10356
 #define KW_NETMASK6 10357
 #define KW_REWRITE 10370
+#define KW_CONDITION 10371
+#define KW_VALUE 10372
 #define KW_YES 10380
 #define KW_NO 10381
 #define KW_IFDEF 10410
