@@ -21,9 +21,48 @@
  *
  */
 
+#include "compat-python.h"
+#include "python-helpers.h"
+#include "syslog-ng.h"
+#include "reloc.h"
+
+void
+_set_python_home(const gchar *python_home)
+{
+  Py_SetPythonHome((gchar *) python_home);
+}
+
+void
+_force_python_home(const gchar *python_home)
+{
+  const gchar *resolved_python_home = get_installation_path_for(python_home);
+  _set_python_home(resolved_python_home);
+}
+
+void
+py_setup_python_home(void)
+{
+#ifdef SYSLOG_NG_PYTHON2_HOME_DIR
+  if (strlen(SYSLOG_NG_PYTHON2_HOME_DIR) > 0)
+    _force_python_home(SYSLOG_NG_PYTHON2_HOME_DIR);
+#endif
+}
+
 void
 py_init_argv(void)
 {
   static char *argv[] = {"syslog-ng"};
   PySys_SetArgvEx(1, argv, 0);
 }
+
+PyObject *
+int_as_pyobject(gint num)
+{
+  return PyInt_FromLong(num);
+};
+
+gint
+pyobject_as_int(PyObject *object)
+{
+  return PyInt_AsLong(object);
+};
