@@ -48,12 +48,13 @@ extern int python_debug;
 #include "python-source.h"
 #include "python-fetcher.h"
 #include "python-logparser.h"
+#include "python-http-header.h"
 #include "python-main.h"
 #include "value-pairs/value-pairs.h"
 #include "logthrsource/logthrsourcedrv.h"
 
 
-#line 57 "modules/python/python-grammar.h" /* yacc.c:1909  */
+#line 58 "modules/python/python-grammar.h" /* yacc.c:1909  */
 
 /* Token type.  */
 #ifndef YYTOKENTYPE
@@ -167,11 +168,11 @@ extern int python_debug;
     KW_TEMPLATE_ESCAPE = 10271,
     KW_TEMPLATE_FUNCTION = 10272,
     KW_DEFAULT_FACILITY = 10300,
-    KW_DEFAULT_LEVEL = 10301,
+    KW_DEFAULT_SEVERITY = 10301,
     KW_PORT = 10323,
     KW_USE_TIME_RECVD = 10340,
     KW_FACILITY = 10350,
-    KW_LEVEL = 10351,
+    KW_SEVERITY = 10351,
     KW_HOST = 10352,
     KW_MATCH = 10353,
     KW_MESSAGE = 10354,
@@ -179,6 +180,8 @@ extern int python_debug;
     KW_TAGS = 10356,
     KW_NETMASK6 = 10357,
     KW_REWRITE = 10370,
+    KW_CONDITION = 10371,
+    KW_VALUE = 10372,
     KW_YES = 10380,
     KW_NO = 10381,
     KW_IFDEF = 10410,
@@ -210,9 +213,11 @@ extern int python_debug;
     KW_FETCH_NO_DATA_DELAY = 10513,
     KW_PYTHON = 10515,
     KW_PYTHON_FETCHER = 10516,
-    KW_CLASS = 10517,
-    KW_IMPORTS = 10518,
-    KW_LOADERS = 10519
+    KW_PYTHON_HTTP_HEADER = 10517,
+    KW_CLASS = 10518,
+    KW_IMPORTS = 10519,
+    KW_LOADERS = 10520,
+    KW_MARK_ERRORS_AS_CRITICAL = 10521
   };
 #endif
 /* Tokens.  */
@@ -323,11 +328,11 @@ extern int python_debug;
 #define KW_TEMPLATE_ESCAPE 10271
 #define KW_TEMPLATE_FUNCTION 10272
 #define KW_DEFAULT_FACILITY 10300
-#define KW_DEFAULT_LEVEL 10301
+#define KW_DEFAULT_SEVERITY 10301
 #define KW_PORT 10323
 #define KW_USE_TIME_RECVD 10340
 #define KW_FACILITY 10350
-#define KW_LEVEL 10351
+#define KW_SEVERITY 10351
 #define KW_HOST 10352
 #define KW_MATCH 10353
 #define KW_MESSAGE 10354
@@ -335,6 +340,8 @@ extern int python_debug;
 #define KW_TAGS 10356
 #define KW_NETMASK6 10357
 #define KW_REWRITE 10370
+#define KW_CONDITION 10371
+#define KW_VALUE 10372
 #define KW_YES 10380
 #define KW_NO 10381
 #define KW_IFDEF 10410
@@ -366,9 +373,11 @@ extern int python_debug;
 #define KW_FETCH_NO_DATA_DELAY 10513
 #define KW_PYTHON 10515
 #define KW_PYTHON_FETCHER 10516
-#define KW_CLASS 10517
-#define KW_IMPORTS 10518
-#define KW_LOADERS 10519
+#define KW_PYTHON_HTTP_HEADER 10517
+#define KW_CLASS 10518
+#define KW_IMPORTS 10519
+#define KW_LOADERS 10520
+#define KW_MARK_ERRORS_AS_CRITICAL 10521
 
 /* Value type.  */
 
