@@ -160,11 +160,11 @@ extern int redis_debug;
     KW_TEMPLATE_ESCAPE = 10271,
     KW_TEMPLATE_FUNCTION = 10272,
     KW_DEFAULT_FACILITY = 10300,
-    KW_DEFAULT_LEVEL = 10301,
+    KW_DEFAULT_SEVERITY = 10301,
     KW_PORT = 10323,
     KW_USE_TIME_RECVD = 10340,
     KW_FACILITY = 10350,
-    KW_LEVEL = 10351,
+    KW_SEVERITY = 10351,
     KW_HOST = 10352,
     KW_MATCH = 10353,
     KW_MESSAGE = 10354,
@@ -172,6 +172,8 @@ extern int redis_debug;
     KW_TAGS = 10356,
     KW_NETMASK6 = 10357,
     KW_REWRITE = 10370,
+    KW_CONDITION = 10371,
+    KW_VALUE = 10372,
     KW_YES = 10380,
     KW_NO = 10381,
     KW_IFDEF = 10410,
@@ -203,7 +205,8 @@ extern int redis_debug;
     KW_FETCH_NO_DATA_DELAY = 10513,
     KW_REDIS = 10515,
     KW_COMMAND = 10516,
-    KW_AUTH = 10517
+    KW_AUTH = 10517,
+    KW_TIMEOUT = 10518
   };
 #endif
 /* Tokens.  */
@@ -314,11 +317,11 @@ extern int redis_debug;
 #define KW_TEMPLATE_ESCAPE 10271
 #define KW_TEMPLATE_FUNCTION 10272
 #define KW_DEFAULT_FACILITY 10300
-#define KW_DEFAULT_LEVEL 10301
+#define KW_DEFAULT_SEVERITY 10301
 #define KW_PORT 10323
 #define KW_USE_TIME_RECVD 10340
 #define KW_FACILITY 10350
-#define KW_LEVEL 10351
+#define KW_SEVERITY 10351
 #define KW_HOST 10352
 #define KW_MATCH 10353
 #define KW_MESSAGE 10354
@@ -326,6 +329,8 @@ extern int redis_debug;
 #define KW_TAGS 10356
 #define KW_NETMASK6 10357
 #define KW_REWRITE 10370
+#define KW_CONDITION 10371
+#define KW_VALUE 10372
 #define KW_YES 10380
 #define KW_NO 10381
 #define KW_IFDEF 10410
@@ -358,6 +363,7 @@ extern int redis_debug;
 #define KW_REDIS 10515
 #define KW_COMMAND 10516
 #define KW_AUTH 10517
+#define KW_TIMEOUT 10518
 
 /* Value type.  */
 
