@@ -33,6 +33,7 @@ def format_module_path_for_intree_modules():
     module_path = ''
     for (root, dirs, files) in os.walk(os.path.abspath(os.path.join(os.environ['top_builddir'], 'modules'))):
         module_path += ':'.join(map(lambda x: root + '/' + x + '/.libs', dirs))
+        module_path += ':'
         module_path += ':'.join(map(lambda x: root + '/' + x, dirs))
         break
     return module_path
@@ -73,6 +74,8 @@ ssl_port_number = port_number + 1
 port_number_syslog = port_number + 2
 port_number_network = port_number + 3
 
+syslog_ng_version = "3.26"
+
 current_dir = os.getcwd()
 try:
     src_dir = os.environ["srcdir"]
